@@ -8,7 +8,7 @@ var splitDocOperatorScenarios = []expressionScenario{
 	{
 		description: "Split empty",
 		document:    ``,
-		expression:  `splitDoc`,
+		expression:  `split_doc`,
 		expected: []string{
 			"D0, P[], (!!null)::\n",
 		},
@@ -16,7 +16,7 @@ var splitDocOperatorScenarios = []expressionScenario{
 	{
 		description: "Split array",
 		document:    `[{a: cat}, {b: dog}]`,
-		expression:  `.[] | splitDoc`,
+		expression:  `.[] | split_doc`,
 		expected: []string{
 			"D0, P[0], (!!map)::{a: cat}\n",
 			"D1, P[1], (!!map)::{b: dog}\n",
